Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/external/gpl3/gcc/dist/gcc/config/vax Don't match an indexed...



details:   https://anonhg.NetBSD.org/src/rev/be6134efc964
branches:  trunk
changeset: 329697:be6134efc964
user:      matt <matt%NetBSD.org@localhost>
date:      Wed Jun 04 16:11:32 2014 +0000

description:
Don't match an indexed address of the form val[reg].

diffstat:

 external/gpl3/gcc/dist/gcc/config/vax/vax.c |  12 ++++++++----
 1 files changed, 8 insertions(+), 4 deletions(-)

diffs (29 lines):

diff -r 8acb27130737 -r be6134efc964 external/gpl3/gcc/dist/gcc/config/vax/vax.c
--- a/external/gpl3/gcc/dist/gcc/config/vax/vax.c       Wed Jun 04 13:52:52 2014 +0000
+++ b/external/gpl3/gcc/dist/gcc/config/vax/vax.c       Wed Jun 04 16:11:32 2014 +0000
@@ -2354,8 +2354,10 @@
 
   if (GET_CODE (lo) == PLUS)
     {
-      /* If PLUS, this must an indexed address so fail.  */
-      if (GET_CODE (XEXP (lo, 0)) == PLUS || !CONST_INT_P (XEXP (lo, 1)))
+      /* If PLUS or MULT, this must an indexed address so fail.  */
+      if (GET_CODE (XEXP (lo, 0)) == PLUS
+         || GET_CODE (XEXP (lo, 0)) == MULT
+         || !CONST_INT_P (XEXP (lo, 1)))
        return false;
       lo_offset = INTVAL (XEXP (lo, 1));
       lo = XEXP(lo, 0);
@@ -2363,8 +2365,10 @@
 
   if (GET_CODE (hi) == PLUS)
     {
-      /* If PLUS, this must an indexed address so fail.  */
-      if (GET_CODE (XEXP (hi, 0)) == PLUS || !CONST_INT_P (XEXP (hi, 1)))
+      /* If PLUS or MULT, this must an indexed address so fail.  */
+      if (GET_CODE (XEXP (hi, 0)) == PLUS
+         || GET_CODE (XEXP (hi, 0)) == MULT
+         || !CONST_INT_P (XEXP (hi, 1)))
        return false;
       hi_offset = INTVAL (XEXP (hi, 1));
       hi = XEXP(hi, 0);



Home | Main Index | Thread Index | Old Index